==> deepin-log-viewer_6.1.8.tar.xz: BUILD/translations/deepin-log-viewer_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="br">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Diskouez er merer restroù</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Diverkañ ar renabl</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Freskaat</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Ha c&apos;hoant ho peus sklaeraat ar renabl?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nullañ</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Kadarnaat</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Pep-tra</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hiziv</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 devezh</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 sizhun</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 miz</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 miz</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Ezporzhiañ</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Pep-tra</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Mallusted</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Kemenn-diwall</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fazi</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Kemenn-diwall</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Notis</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Titouroù</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Dizraenañ</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Kevreañ</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Loc&apos;hañ</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Lazhañ</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html))</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nullañ</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Ezporzhiañ ur restr</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Mare:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Listenn an arloadoù:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Statud:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Doare darvoud:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Implijader:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Ober:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Anv-implijader:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Enrolladur al loc&apos;hañ</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Enrolladur al lazhañ</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Enrolladur ar c&apos;hevreañ</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Kemenn-diwall</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Dizraenañ</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Titouroù</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fazi</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Mallusted</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Kemenn-diwall</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Notis</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Lenner renabloù</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Log Viewer (Gweler renabloù) a zo un ostilh talvoudus anezhañ evit diskouez renabloù ar sistem.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Disoc&apos;h ebet d&apos;an enklask</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Klask</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Live</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Prosesus</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Deiziad hag eurvezh</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Titouroù</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Implijader</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Mammenn</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Ober</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statud</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Doare darvoud</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Anv-implijader</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Live:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Prosesus:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Deiziad hag eurvezh:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Titouroù:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Implijader:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Deiziad hag eurvezh</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Renabl sistem</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Renabl ar graoñenn</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Renabl al loc&apos;hañ</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Renabl dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Renabl Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Renabl an arloañ</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Darvoud lazhañ el loc&apos;hañ</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.1.15.tar.xz: BUILD/translations/deepin-log-viewer_br.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="br">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Diskouez er merer restroù</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Diverkañ ar renabl</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Freskaat</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Ha c&apos;hoant ho peus sklaeraat ar renabl?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nullañ</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Kadarnaat</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Pep-tra</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hiziv</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 devezh</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 sizhun</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 miz</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 miz</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Ezporzhiañ</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Pep-tra</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Mallusted</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Kemenn-diwall</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fazi</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Kemenn-diwall</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Notis</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Titouroù</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Dizraenañ</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Kevreañ</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Loc&apos;hañ</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Lazhañ</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remote</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Document audit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TESTENN (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nullañ</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Ezporzhiañ ur restr</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Mare:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status:</source>
        <translation>Statud:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Doare darvoud:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Implijader:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Ober:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Anv-implijader:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Enrolladur al loc&apos;hañ</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Enrolladur al lazhañ</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Enrolladur ar c&apos;hevreañ</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Kemenn-diwall</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Dizraenañ</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Titouroù</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fazi</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Mallusted</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Kemenn-diwall</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Notis</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Lenner renabloù</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Log Viewer (Gweler renabloù) a zo un ostilh talvoudus anezhañ evit diskouez renabloù ar sistem.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Disoc&apos;h ebet d&apos;an enklask</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Klask</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Live</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Prosesus</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Deiziad hag eurvezh</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Titouroù</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Implijader</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Mammenn</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Ober</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statud</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Doare darvoud</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Anv-implijader</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Live:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Prosesus:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Deiziad hag eurvezh:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Titouroù:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Implijader:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Deiziad hag eurvezh</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Renabl sistem</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Renabl ar graoñenn</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Renabl al loc&apos;hañ</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Renabl dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Renabl Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Renabl an arloañ</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Darvoud lazhañ el loc&apos;hañ</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>10 sec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
